@@ -5,8 +5,13 @@ function(data, filename="species_descriptions.txt") {
   }
   message("Assuming the columns are ordered as: Character_in_description, complement, separator, and the species in the remaining columns")
   cat(" ", fill=T)
+  data.frame(as.matrix(data), stringsAsFactors = F) -> data
   data[,1:3] -> model
   data[,4:ncol(data)] -> spp.data
+  if (class(spp.data) != "data.frame") {
+    data.frame(as.matrix(spp.data), stringsAsFactors = F) -> spp.data
+    colnames(spp.data) <- colnames(data)[4]
+  }
   colnames(spp.data) -> spp
   cat("Species Descriptions", file=filename)
   spaces <-function(x) return(gsub("(?<=[\\s])\\s*|^\\s+$", "", x, perl=TRUE))
